Sketchy filled contour and 2-D density bands
Source:R/geom-sketch-contour-filled.R
geom_sketch_contour_filled.Rdgeom_sketch_contour_filled() draws hand-drawn filled contour bands of a
surface (the sketch analogue of ggplot2::geom_contour_filled()); it needs
x, y, and z. geom_sketch_density_2d_filled() fills the bands of a 2-D
kernel density estimate (ggplot2::geom_density_2d_filled()); it needs x
and y and uses MASS.
Usage
GeomSketchContourFilled
geom_sketch_contour_filled(
mapping = NULL,
data = NULL,
stat = "contour_filled",
position = "identity",
...,
bins = NULL,
binwidth = NULL,
breaks = NULL,
roughness = 0.7,
bowing = 0.5,
n_passes = 2L,
seed = NULL,
fill_style = "solid",
hachure_angle = 45,
hachure_gap = 0.04,
fill_weight = 0.5,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_sketch_density_2d_filled(
mapping = NULL,
data = NULL,
stat = "density_2d_filled",
position = "identity",
...,
roughness = 0.7,
bowing = 0.5,
n_passes = 2L,
seed = NULL,
fill_style = "solid",
hachure_angle = 45,
hachure_gap = 0.04,
fill_weight = 0.5,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_sketch_density2d_filled(
mapping = NULL,
data = NULL,
stat = "density_2d_filled",
position = "identity",
...,
roughness = 0.7,
bowing = 0.5,
n_passes = 2L,
seed = NULL,
fill_style = "solid",
hachure_angle = 45,
hachure_gap = 0.04,
fill_weight = 0.5,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)Arguments
- mapping
Set of aesthetic mappings created by
ggplot2::aes().- data
Data to display.
- stat
Statistical transformation (default
"identity").- position
Position adjustment (default
"identity").- ...
Other arguments passed on to the layer.
- bins
Number of contour bins. Overridden by
binwidthorbreaks.- binwidth
Distance between contour bins.
- breaks
Explicit numeric contour breaks; overrides
bins/binwidth.- roughness
Non-negative roughness parameter (0 = straight). Default 1.
- bowing
Non-negative bowing multiplier. Default 1.
- n_passes
Number of stroke passes for the double-stroke effect. Default 2.
- seed
Integer seed for reproducibility.
NULLusesgetOption("ggsketch.seed", 1L).- fill_style
Band fill:
"solid"(default),"hachure", or"cross_hatch". Other styles degrade to"hachure".- hachure_angle
Fill line angle in degrees. Default 45.
- hachure_gap
Fill line gap (npc fraction). Default 0.04.
- fill_weight
Stroke weight for fill lines. Default 0.5.
- na.rm
If
FALSE(default), missing values are removed with a warning.- show.legend
Logical. Should this layer be included in the legend?
- inherit.aes
If
FALSE, override the default aesthetics.
Details
Unlike the contour line geoms, each band is a region that may contain holes
(the next level up, cut out). The fill is painted with a hole-aware
scan-line so the holes stay empty, even for fill_style = "hachure".
See also
Other sketch-geoms:
GeomSketchAbline,
GeomSketchArrow,
GeomSketchBoxplot,
GeomSketchBracket,
GeomSketchCallout,
GeomSketchChicklet,
GeomSketchCol,
GeomSketchCurve,
GeomSketchDotplot,
GeomSketchDumbbell,
GeomSketchEdge,
GeomSketchEllipse,
GeomSketchEngrave,
GeomSketchGantt,
GeomSketchHex,
GeomSketchLine,
GeomSketchLinerange,
GeomSketchLollipop,
GeomSketchMarkCircle,
GeomSketchMarkHull,
GeomSketchPath,
GeomSketchPoint,
GeomSketchPolygon,
GeomSketchRect,
GeomSketchRibbon,
GeomSketchRug,
GeomSketchSegment,
GeomSketchSfPolygon,
GeomSketchSlope,
GeomSketchSmooth,
GeomSketchSpoke,
GeomSketchTextRepel,
GeomSketchViolin,
StatSketchBeeswarm,
StatSketchCalendar,
StatSketchDensityRidges,
StatSketchFunnel,
StatSketchPie,
StatSketchPyramid,
StatSketchRadar,
StatSketchStream,
StatSketchTreemap,
StatSketchWaffle,
StatSketchWaterfall,
annotate_sketch(),
annotate_sketch_arrow(),
annotate_sketch_callout(),
annotate_sketch_highlight(),
geom_sketch_alluvial(),
geom_sketch_arc_diagram(),
geom_sketch_bin2d(),
geom_sketch_bump(),
geom_sketch_chord(),
geom_sketch_contour(),
geom_sketch_count(),
geom_sketch_dendrogram(),
geom_sketch_density(),
geom_sketch_density2d(),
geom_sketch_ecdf(),
geom_sketch_function(),
geom_sketch_histogram(),
geom_sketch_jitter(),
geom_sketch_marimekko(),
geom_sketch_mosaic(),
geom_sketch_parallel(),
geom_sketch_qq(),
geom_sketch_quantile(),
geom_sketch_rose(),
geom_sketch_sunburst(),
geom_sketch_text(),
sketch_graph()
Examples
library(ggplot2)
ggplot(faithfuld, aes(waiting, eruptions, z = density)) +
geom_sketch_contour_filled(seed = 1L) +
theme_sketch()