Learn R Programming

ggsketch (version 2.0.0)

hachure_fill: Fill a polygon with hachure lines using the AET scan-line algorithm

Description

Fill a polygon with hachure lines using the AET scan-line algorithm

Usage

hachure_fill(
  px,
  py,
  hachure_gap = 0.1,
  hachure_angle = 45,
  roughness = 0,
  bowing = 0,
  seed = NULL
)

Value

A list of 2-column (x, y) matrices, one per fill line (roughened if roughness > 0, otherwise two-point straight segments).

Arguments

px, py

Polygon vertex coordinates in inch space. May be open or closed.

hachure_gap

Spacing between fill lines (inches). Default 0.1.

hachure_angle

Fill angle (degrees). Default 45.

roughness

Roughness applied to each fill line. Default 0 (straight).

bowing

Bowing applied to each fill line. Default 0.

seed

Integer seed.

See Also

Other sketch-core: arrowhead(), curve_fill(), engrave_fill(), engrave_ladder(), hachure_fill_multi(), leader_path(), repel_layout(), rough_arc(), rough_bezier(), rough_ellipse(), roughen_polyline(), sketch_arrowheads(), sketch_fill(), sketch_fill_multi(), spray_scatter(), stroke_profile(), stroke_ribbon(), treemap_layout(), wash_bleed(), watercolor_wash(), watercolor_wash_multi()