Lays out one rectangle per value inside the box [x, x + width] x [y, y + height], with area proportional to the value and aspect ratios kept
close to 1. Returns rectangles in the original input order.
See also
Other sketch-core:
arrowhead(),
curve_fill(),
engrave_fill(),
engrave_ladder(),
hachure_fill(),
hachure_fill_multi(),
leader_path(),
repel_layout(),
rough_arc(),
rough_bezier(),
rough_ellipse(),
roughen_polyline(),
sketch_arrowheads(),
sketch_fill(),
sketch_fill_multi(),
spray_scatter(),
stroke_profile(),
stroke_ribbon(),
wash_bleed(),
watercolor_wash(),
watercolor_wash_multi()
Examples
treemap_layout(c(6, 3, 2, 1))
#> xmin xmax ymin ymax
#> 1 0.0000000 0.5000000 0.0 1.0
#> 2 0.5000000 1.0000000 0.0 0.5
#> 3 0.5000000 0.8333333 0.5 1.0
#> 4 0.8333333 1.0000000 0.5 1.0